pub enum SvgNesting {
Standalone,
ReferencedFromImageElement,
}Expand description
Whether an SVG document is being rendered standalone or referenced from an <image> element.
Normally, the coordinate system used when rendering a toplevel SVG is determined from the
initial viewport and the <svg> element’s viewBox and preserveAspectRatio attributes.
However, when an SVG document is referenced from an <image> element, as in <image href="foo.svg"/>,
its preserveAspectRatio needs to be ignored so that the one from the <image> element can
be used instead. This lets the parent document (the one with the <image> element) specify
how it wants the child SVG to be scaled into the viewport.
Variants